#
# spec file for package NumCpp
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __builder ninja
Name:           NumCpp
Version:        2.14.1
Release:        1.1
Summary:        C++ implementation of the Python Numpy library
License:        MIT
URL:            https://github.com/dpilger26/NumCpp
Source:         %{url}/archive/refs/tags/Version_%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE NumCpp-pytest-link-python.patch gh#dpilger26/NumCpp#222 badshah400@gmail.com -- Fix python linking on openSUSE for pytest based tests
Patch0:         NumCpp-pytest-link-python.patch
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gtest
BuildRequires:  libboost_date_time-devel
BuildRequires:  libboost_log-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  python3-pybind11-devel
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(tbb)

%description
NumCpp is a templatized header-only C++ implementation of the Python NumPy library.

%package devel
Summary:        Header files for NumCpp
Requires:       libboost_date_time-devel
Requires:       libboost_headers-devel
Requires:       libboost_log-devel
Requires:       libboost_numpy3-devel
Requires:       libboost_python3-devel
Requires:       libboost_system-devel
Requires:       libboost_thread-devel
Requires:       python3-pybind11-devel
BuildArch:      noarch

%description devel
This package provides the header files for compiling code using NumCpp.

%prep
%autosetup -p1 -n %{name}-Version_%{version}

%build
%cmake \
  -DNUMCPP_USE_MULTITHREAD:BOOL=ON \
  -DBUILD_DOCS:BOOL=ON \
  -DBUILD_TESTS:BOOL=ON \
  -DBUILD_MULTIPLE_TEST:BOOL=ON \
  -DBUILD_CPPCHECK_TEST:BOOL=ON \
  -Wno-dev \
%{nil}
%cmake_build

%install
%cmake_install

%check
%ctest

%files devel
%license LICENSE
%doc README.md
%{_includedir}/%{name}.hpp
%{_includedir}/%{name}/
%{_datadir}/%{name}/

%changelog
* Tue May  6 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.14.1:
  * Make behavior of linalg::lstsq match NumPy when inputting a
    multidimensional b array [gh#dpilger26/NumCpp#229].
* Sun Feb  9 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.14.0:
  * added argpartition() for gh#dpilger26/NumCpp#225.
- Drop upstreamed or otherwise no longer required patches:
  * NumCpp-disable-pytest.patch
  * NumCpp-add-tests.patch
- Add NumCpp-pytest-link-python.patch: Fix linking to python when
  building for openSUSE [gh#dpilger26/NumCpp#222].
* Tue Jan 14 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.13.0:
  * Added putAlongAxis() [gh#dpilger26/NumCpp#217].
  * Fixed random seeding [gh#dpilger26/NumCpp#218].
  * Fixed error in fromfile() that limited filesize to 4GB
    [gh#dpilger26/NumCpp#219].
- Update NumCpp-disable-pytest.patch: In addition to disabling
  pytest tests (not yet resolved), uncomment to enable gtest based
  tests [gh#dpilger26/NumCpp#222].
- Add NumCpp-add-tests.patch: Add `multitest` and `cppcheck` tests
  to ctest to make testing during %%check easy.
- Restore ninja for build, does not affect issues related to
  python linking errors during tests (disabled by
  NumCpp-disable-pytest.patch).
* Mon Dec 16 2024 Atri Bhattacharya <badshah400@gmail.com>
- Add NumCpp-disable-pytest.patch: Temporarily disable pytests
  that are incorrectly configured for pybind11; fixes build
  failures.
* Thu Oct 19 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.12.1:
  * updated TRUE/FALSE enum fields to YES/NO to deconflict with
    other library's terrible macro practice of #defining
    TRUE/FALSE
* Sun Oct  8 2023 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
